####################################################
##           Bender oneliners  V2.0               ##
## 02/05/11 <oldsoldier@gshellz.org>              ##
## an updated version of Duke oneliners written   ##
##            by <fan2000@gmx.net>                ##
##                                                ##
####################################################
# Description:                                     #
# Simple random quote script filled with best      #
# of Bender oneliners.                             #
####################################################
# Setup:                                           #
# extract to your eggdrop/scripts directory        #
# add this to your conf:                           #
# source scripts/benderv2.tcl                      #
####################################################
# Configuration:                                   #
# via DCC:                                         #
# .chanset <#channel> +bquote    - enables         #
# .chanset <#channel> -bquote    - disables        #
####################################################
# Usage:                                           #
# !bender         - random quote                   #
# !bender <num>   - quote <num> from quotes list   #
####################################################
#Credits:                                          #
# Bass@undernet for the char filter concept        #
####################################################

# define channel flag to enable quotes.
setudef flag bquote
# define trigger
#you can change the trigger if you want, I like to use !

bind pub  -|- !bender     pub_bender
#set array
#one liners go here
#one per line format is "blah,blah,yadda yadda"
set randbender {
"This is the worst kind of discrimination. The kind against me!"
"Oh. Your. God."
"My life, and by extension everyone else's is meaningless."
"I'm Bender, baby, please insert liquor!"
"They're not very heavy, but you don't hear me not complaning."
"Everybody's a jerk. You, me, this jerk."
"I hate the people that love me and they hate me."
"Do I preach to you while you're lying stoned in the gutter? No."
"Tempers are wearing thin. Let's hope some robot doesn't kill everybody."
"Bite my shiny metal ass!"
"I'm gonna go build my own theme park! With blackjack and hookers! In fact, forget the park!"
"That's no alien spaceship-that's my ass!"
"Bribe is such an ugly word. I prefer extortion. The X makes it sound cool."
"Life can be hilariously cruel."
"Leela cracked corn, and i dont care. Fry cracked corn, i still dont care. Bender cracked corn, and he is great! Take that you stupid corn!"
"Let's face it, comedy's a dead art form. Tragedy, now that's funny."
"Great is OK, but amazing would be GREAT."
"Who are you, and why should I care?"
"What kind of party is this? There's no booze and only one hooker."
"I was thinking Benderbrau if it's an ale, Botweiser if it's a lager. "
"Ahhh, what an awful dream. Ones and zeroes everywhere... and I thought I saw a two."
"What do you mean 'we,' flesh-tube?"
"This calls for a party, baby. I'm ordering 100 kegs, 100 hookers and 100 Elvis impersonators that aren't above a little hooking should the occasion arise."
"Let me put it this way, after I leave here I'm getting a memory enema."
"I have everything I ever wanted: money, wealth, riches..."
"Of course, it would all require split second robot timing. That's where I come in. You see, I own a watch."
"Aww! Its anus looks like an asterisk."
"I can't run anymore, I'll have to skip."
"I never said I wasn't a drama queen."
"If you hate intolerance and being punched in the face by me, please support Proposition Infinity."
"But of everyone I ever dated, you're probably in the top ten."
"Is there an app for kissing my shiny metal ass?"
"Let's at least throw this TV away, the batteries in the remote are running low."
"I need mouth-to-ass resuscitation ... I'll die happy knowing you fell for that."
"Wow! The original party worm! Are you ready to get down, get funky with us?"
"It is every robot's duty to give his life for the good of humanity. Oh, crap!"
"The auxiliary power's out, and they spilled my cocktail."
"Uh-oh, nerds!"
"You're all losers. My name's Bender."
"Hmm, OK. But I'll need 10 kegs of beer, a continuous tape of Louie Louie and a regulation two-storey panty-raid ladder."
"Well, looks like the party's winding down. Let's take a road trip to Tijuana and get Fatbot some action."
"Hey, wait! Gimme a do-over! My cheating chip malfunctioned!"
"Well, I'm tired of this room and everyone in it. If you'll excuse me, I'm gonna pop over to the casino for the next 135 hours!"
"Gimmie you're biggest, strongest, cheapest drink."
"I'm not actually rich. I'm a fraud. A poor, lazy, sexy fraud. This isn't even a real bow-tie, it's magnetic"
"You all go without me. I'm gonna take one last look around. You know, for, uh, stuff to steal."
"I'm gonna drink till I reboot!"
"No, I'm whacked out on life. My friends, I found religion."
"Y'know, as a major Hollywood director, I'll be holding auditions tonight for my next movie. And even though you're all young and naive, I think you might just have what it takes."
"No, of course not! It was... uh... porno! Yeah, that's it!"
"Hey. Bender the Offender doesn't need YOU. Bender the Offender doesn't need ANYBODY!"
"Well, obviously I need floozies."
"Of all the friends I've had... you're the first."
"Oh, so just cause a robot wants to kill humans, that makes him a radical?"
"Now, your basic human is between 3 and 25 feet tall, and is made of a hairy, oily goo wrapped in a t-shirt."
"I've never made anyone's life easier and you know it!"
"Hey, nice seats! We're close enough to when you knock a player down with a beer bottle, he stays down."
"Oh, I get it, make the robot do all the work!"
"Well I'm not doing it! It's a robot holiday."
"Alright, I'll go. But so help me, I'll hold a grudge against every last stinking one of you for the rest of your lives."
"Death to humans!"
"Many said I was too extreme when I first called for the annihilation of the human species, as well as some of the more cunning monkeys. But after living on Earth, I can tell you that I am, if anything, too merciful!"
"I love this planet. I've got wealth, fame and access to the depths of sleaze that those things bring."
"He's pending for a bending..."
"I just know these things. I've got what they call a gaydar."
"I'm trying to watch my input. I need plenty of wholesome, nutritious alcohol."
"Those could be anyone's thoughts, fat ass!"
"Hey. What I don't do is none of your business."
"That's right! I'm sober and crazy and I don't know what I might do!"
"Oh, no room for Bender, huh? Fine, I'll go build my own Lunar Lander! With blackjack and hookers! In fact, forget the Lunar Lander and the blackjack! Ah, screw the whole thing."
"Yeah! You're the kind of guy who visits Jerusalem and doesn't want to see the Sexeteria!"
"Come on, it's just like making love. Y'know; left, down, rotate 62 degrees, engage rotor."
"What do you mean 'we', mammal?"
"Well, okay. But I don't want people thinking we're robo-sexuals, so if anyone asks, you're my debugger."
}
#pub_bender:
proc pub_bender {nick uhost hand chan arg} {
 global randbender
 set arg [charfilter_bender $arg] 
 set chan [string tolower $chan]
 if {![channel get $chan bquote]} { return 0 }
 if {$arg == ""} {
  set brnd [rand [llength $randbender]]
  putchan $chan "[lindex $randbender [expr $brnd]] "
  return 1  
 }

 set bender_nr [lindex $arg 0]
 
 if { [isnumber [lindex $arg 0]] != 1} {
  putserv "NOTICE $nick : enter a number pitiful human!"
  return 1 
 }

 set bender_oneliner [lindex $randbender [expr $bender_nr -1]]
  
 if {$bender_oneliner == ""} { 
  putserv "NOTICE $nick : no valid oneliner found flesh-tube!"
  return 1
 }
   
 putchan $chan "$bender_oneliner" 
 return 1
  
}
#charfilter
proc charfilter_bender {x {y ""}} {
	for {set i 0} {$i < [string length $x]} {incr i} {
		switch -- [string index $x $i] {
			"\"" {append y "\\\""}
			"\\" {append y "\\\\"}
			"\[" {append y "\\\["}
			"\]" {append y "\\\]"}
			"\}" {append y "\\\}"}
			"\{" {append y "\\\{"}
			default {append y [string index $x $i]}
		}
	}
	return $y
}
####################################################
putlog "Bender oneliners v2.0 LOADED!"
#All done!
